@@ -225,7 +225,7 @@ class Provider(PersonProvider):
         'Анатольевич', 'Андреевич', 'Анисимович', 'Антипович', 'Антонович',
         'Ануфриевич', 'Арсенович', 'Арсеньевич', 'Артёмович', 'Артемьевич',
         'Артурович', 'Архипович', 'Афанасьевич', 'Бенедиктович', 'Богданович',
-        'Бориславич', 'Бориславович', 'Борисович', 'Брониславович',
+        'Бориславович', 'Бориславович', 'Борисович', 'Брониславович',
         'Валентинович', 'Валерианович', 'Валерьевич', 'Валерьянович',
         'Васильевич', 'Венедиктович', 'Викентьевич', 'Викторович', 'Виленович',
         'Вилорович', 'Витальевич', 'Владиленович', 'Владиславович',
@@ -238,7 +238,7 @@ class Provider(PersonProvider):
         'Елисеевич', 'Еремеевич', 'Ермилович', 'Ермолаевич', 'Ерофеевич',
         'Ефимович', 'Ефимьевич', 'Ефремович', 'Ефстафьевич', 'Жанович',
         'Жоресович', 'Захарьевич', 'Зиновьевич', 'Игнатович', 'Игнатьевич',
-        'Игоревич', 'Измаилович', 'Изотович', 'Иларионовичх', 'Ильич',
+        'Игоревич', 'Измаилович', 'Изотович', 'Иларионович', 'Ильич',
         'Ильясович', 'Иосипович', 'Иосифович', 'Исидорович', 'Марсович',
         'Матвеевич', 'Тарасович', 'Теймуразович', 'Терентьевич', 'Тимурович',
         'Тихонович', 'Трифонович', 'Трофимович', 'Устинович', 'Фадеевич',
@@ -259,7 +259,7 @@ class Provider(PersonProvider):
         'Вячеславовна', 'Геннадиевна', 'Георгиевна', 'Геннадьевна',
         'Григорьевна', 'Даниловна', 'Дмитриевна', 'Евгеньевна',
         'Егоровна', 'Ефимовна', 'Ждановна', 'Захаровна', 'Ивановна', 'Игоревна',
-        'Ильинична', 'Кирилловна', 'Кузминична', 'Константиновна',
+        'Ильинична', 'Кирилловна', 'Кузьминична', 'Константиновна',
         'Кузьминична', 'Леонидовна', 'Леоновна', 'Львовна', 'Макаровна',
         'Матвеевна', 'Михайловна', 'Максимовна', 'Мироновна', 'Натановна',
         'Никифоровна', 'Ниловна', 'Наумовна', 'Николаевна', 'Олеговна',
@@ -290,7 +290,7 @@ class Provider(PersonProvider):
         'Малагасийский', 'Маршалльский', 'Маори', 'Македонский', 'Малаялам',
         'Монгольский', 'Маратхи', 'Малайский', 'Мальтийский', 'Непальский',
         'Нидерландский', 'Норвежский', 'Навахо', 'Оромо', 'Ория',
-        'Осетинский', 'Пали', 'Польский', 'Пушту', 'Португальский',
+        'Осетинский', 'Пали', 'Польский', 'Пуштунский', 'Португальский',
         'Романшский', 'Румынский', 'Русский', 'Киньяруанда',
         'Санскрит', 'Сардинский', 'Санго', 'Сингальский',
         'Словацкий', 'Словенский', 'Самоанский', 'Сомалийский', 'Албанский',
